@@ -11,7 +11,16 @@
 #' @export
 #'
 
-get_congress_version <- function(){
-  vers <- suppressWarnings(read.csv(url("https://ippsr.msu.edu/congresshelper")))
-  message("You are using CongressData version: ",vers$version)
-}
\ No newline at end of file
+get_congress_version <- function() {
+  vers <- tryCatch(
+    suppressWarnings(read.csv(url("https://ippsr.msu.edu/congresshelper"))),
+    error = function(e) NA
+  )
+  
+  if (is.na(vers)) {
+    message("CongressData version: not available")
+  } else {
+    message("You are using CongressData version: ", vers$version)
+  }
+}
+
