@@ -2,7 +2,7 @@
 # prints when the package is attached using library()
 .onAttach <- function(libname, pkgname) {
   packageStartupMessage("Please cite:\n")
-  packageStartupMessage("Grossmann, M., Lucas, C., McCrain, J, & Ostrander, I. (2022). CongressData.")
-  packageStartupMessage("East Lansing, MI: Institute for Public Policy and Social Research (IPPSR).")
+  packageStartupMessage("Grossmann, Matt, Caleb Lucas, and Benjamin Yoel. Introducing CongressData and Correlates of State Policy")
+  packageStartupMessage("East Lansing, MI: Institute for Public Policy and Social Research (IPPSR), 2024.")
   packageStartupMessage("\nRun `CongressData::get_congress_version()` to print the version of CongressData the package is using.\n")
 }
